<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    password_censor
 */

/**
 * Hook class.
 */
class Hook_addon_registry_password_censor
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the current version of this addon (usually software major, software minor, addon build).
     * Put the comment "// addon_version_auto_update" to the right of the return if you want release tools to automatically update this according to software version and find_addon_effective_md5.
     *
     * @return SHORT_TEXT Version number
     */
    public function get_version() : string
    {
        return '11.0.2'; // addon_version_auto_update 0782de8e700e2dfb0a7b2de6ee5f0394
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return 11.9;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Development';
    }

    /**
     * Get the addon author.
     *
     * @return string The author
     */
    public function get_author() : string
    {
        return 'Chris Graham';
    }

    /**
     * Find other authors.
     *
     * @return array A list of co-authors that should be attributed
     */
    public function get_copyright_attribution() : array
    {
        return [];
    }

    /**
     * Get the addon licence (one-line summary only).
     *
     * @return string The licence
     */
    public function get_licence() : string
    {
        return 'Licensed on the same terms as ' . brand_name();
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'Regularly wipe old passwords posted in private on your website, in case it is ever hacked.

In detail:
This is a system scheduler hook that regularly censors anything looking like a password stored in support ticket posts over 60 days old to limit the potential fallout if your ticket system ever got compromised.

[tt]encrypt[/tt] and [tt]self_destruct[/tt] Comcode tags are also added; [tt]encrypt[/tt] will use the configured public and private keys to encrypt text, and [tt]self_destruct[/tt] will destroy itself after 30 days (while also not appearing in notifications).
';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => ['System scheduler'],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/admin/component.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'data_custom/password_censor.php',
            'sources_custom/hooks/systems/addon_registry/password_censor.php',
            'sources_custom/hooks/systems/comcode/encrypt.php',
            'sources_custom/hooks/systems/comcode/self_destruct.php',
            'sources_custom/hooks/systems/contentious_overrides/password_censor.php',
            'sources_custom/hooks/systems/cron/password_censor.php',
            'sources_custom/hooks/systems/startup/password_censor.php',
            'sources_custom/hooks/systems/symbols/DECRYPT.php',
            'sources_custom/password_censor.php',
            'themes/default/javascript_custom/password_censor.js',
            'themes/default/templates_custom/COMCODE_ENCRYPT.tpl',
            'themes/default/templates_custom/COMCODE_SELF_DESTRUCT.tpl',
        ];
    }
}
